| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.Route53Domains.Types.Tag
Description
Documentation
Each tag includes the following elements.
See: newTag smart constructor.
Constructors
| Tag' | |
Instances
| FromJSON Tag Source # | |
| ToJSON Tag Source # | |
Defined in Amazonka.Route53Domains.Types.Tag | |
| Generic Tag Source # | |
| Read Tag Source # | |
| Show Tag Source # | |
| NFData Tag Source # | |
Defined in Amazonka.Route53Domains.Types.Tag | |
| Eq Tag Source # | |
| Hashable Tag Source # | |
Defined in Amazonka.Route53Domains.Types.Tag | |
| type Rep Tag Source # | |
Defined in Amazonka.Route53Domains.Types.Tag type Rep Tag = D1 ('MetaData "Tag" "Amazonka.Route53Domains.Types.Tag" "amazonka-route53-domains-2.0-6iruRSkjgLuDp958hFs0e" 'False) (C1 ('MetaCons "Tag'" 'PrefixI 'True) (S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)))) | |
Create a value of Tag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:Tag', tag_key - The key (name) of a tag.
Valid values: A-Z, a-z, 0-9, space, ".:/=+\-@"
Constraints: Each key can be 1-128 characters long.
$sel:value:Tag', tag_value - The value of a tag.
Valid values: A-Z, a-z, 0-9, space, ".:/=+\-@"
Constraints: Each value can be 0-256 characters long.